==> activity-center-biz-1.2.6.8.gey-20161013.075400-1-sources.jar: cn/com/duiba/activity/center/biz/service/activity_brick/impl/PopupActivityBrickServiceimpl.java <==
package cn.com.duiba.activity.center.biz.service.activity_brick.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.activity_brick.PopupActivityBrickDto;
import cn.com.duiba.activity.center.biz.dao.activity_brick.PopupActivityBrickDao;
import cn.com.duiba.activity.center.biz.service.activity_brick.PopupActivityBrickService;

/** 
 * ClassName:PopupActivityBrickServiceimpl.java <br/>
 * @author  gey 
 * @date 创建时间：2016年10月12日 下午3:08:55 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
@Service
public class PopupActivityBrickServiceimpl implements PopupActivityBrickService {

	@Autowired
	private PopupActivityBrickDao popupActivityBrickDao;
	
	@Override
	public PopupActivityBrickDto insert(PopupActivityBrickDto brick) {
		return popupActivityBrickDao.insert(brick);
	}

	@Override
	public Integer update(PopupActivityBrickDto brick) {
		return popupActivityBrickDao.update(brick);
	}

	@Override
	public PopupActivityBrickDto findById(Long id) {
		return popupActivityBrickDao.findById(id);
	}

	@Override
	public Integer deleteById(Long id) {
		return popupActivityBrickDao.deleteById(id);
	}

	@Override
	public Integer showBrick(Long id) {
		return popupActivityBrickDao.showBrick(id);
	}

	@Override
	public Integer hiddenBrick(Long id) {
		return popupActivityBrickDao.hiddenBrick(id);
	}

	@Override
	public List<PopupActivityBrickDto> findPage(Map<String, Object> paramMap) {
		return popupActivityBrickDao.findPage(paramMap);
	}

	@Override
	public Long findPageCount(Map<String, Object> paramMap) {
		return popupActivityBrickDao.findPageCount(paramMap);
	}
}

==> activity-center-biz-1.2.6.9.gey2-20161017.021219-1-sources.jar: cn/com/duiba/activity/center/biz/service/activity_brick/impl/PopupActivityBrickServiceimpl.java <==
package cn.com.duiba.activity.center.biz.service.activity_brick.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.activity_brick.PopupActivityBrickDto;
import cn.com.duiba.activity.center.biz.dao.activity_brick.PopupActivityBrickDao;
import cn.com.duiba.activity.center.biz.service.activity_brick.PopupActivityBrickService;

/** 
 * ClassName:PopupActivityBrickServiceimpl.java <br/>
 * @author  gey 
 * @date 创建时间：2016年10月12日 下午3:08:55 
 * @version 1.0 
 * @parameter  
 * @since   JDK 1.6
 */
@Service
public class PopupActivityBrickServiceimpl implements PopupActivityBrickService {

	@Autowired
	private PopupActivityBrickDao popupActivityBrickDao;
	
	@Override
	public PopupActivityBrickDto insert(PopupActivityBrickDto brick) {
		return popupActivityBrickDao.insert(brick);
	}

	@Override
	public Integer update(PopupActivityBrickDto brick) {
		return popupActivityBrickDao.update(brick);
	}

	@Override
	public PopupActivityBrickDto findById(Long id) {
		return popupActivityBrickDao.findById(id);
	}

	@Override
	public Integer deleteById(Long id) {
		return popupActivityBrickDao.deleteById(id);
	}

	@Override
	public Integer showBrick(Long id) {
		return popupActivityBrickDao.showBrick(id);
	}

	@Override
	public Integer hiddenBrick(Long id) {
		return popupActivityBrickDao.hiddenBrick(id);
	}

	@Override
	public List<PopupActivityBrickDto> findPage(Map<String, Object> paramMap) {
		return popupActivityBrickDao.findPage(paramMap);
	}

	@Override
	public Long findPageCount(Map<String, Object> paramMap) {
		return popupActivityBrickDao.findPageCount(paramMap);
	}

	@Override
	public PopupActivityBrickDto findByName(String name) {
		return popupActivityBrickDao.findByName(name);
	}
}
